#
# spec file for package glpk
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname   libglpk36
Name:           glpk
Version:        4.55
Release:        6.1
Summary:        GNU Linear Programming Kit
License:        GPL-3.0
Group:          Productivity/Scientific/Math
Url:            http://www.gnu.org/software/glpk/glpk.html
#DL-URL:        http://ftp.gnu.org/gnu/glpk/
Source:         http://ftp.gnu.org/gnu/glpk/%{name}-%{version}.tar.gz
Source2:        http://ftp.gnu.org/gnu/glpk/%{name}-%{version}.tar.gz.sig
Source3:        %{name}.keyring
BuildRequires:  ghostscript
BuildRequires:  texlive
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The GLPK package is intended for solving large-scale linear
programming, mixed integer programming, and other related problems. It
is a set of routines written in ANSI C and organized in the form of a
callable library.

%package        devel
Summary:        GNU Linear Programming Kit
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description    devel
The GLPK package is intended for solving large-scale linear
programming, mixed integer programming, and other related problems. It
is a set of routines written in ANSI C and organized in the form of a
callable library.

%package     -n %{lname}
Summary:        GNU Linear Programming Kit
Group:          System/Libraries

%description -n %{lname}
The GLPK package is intended for solving large-scale linear
programming, mixed integer programming, and other related problems. It
is a set of routines written in ANSI C and organized in the form of a
callable library.

%package doc
Summary:        GNU Linear Programming Kit
Group:          Documentation/Other
%if 0%{?suse_version} >= 1120 || 0%{?fedora_version}
BuildArch:      noarch
%endif

%description doc
The GLPK package is intended for solving large-scale linear
programming, mixed integer programming, and other related problems. It
is a set of routines written in ANSI C and organized in the form of a
callable library.

%prep
%{?gpg_verify: %gpg_verify %{SOURCE2}}
%setup -q

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_docdir}/%{name}/examples
cp examples/*.{mod,c,dat,mps,lp} %{buildroot}%{_docdir}/%{name}/examples
mkdir %{buildroot}%{_docdir}/%{name}/doc
cp doc/{*.txt,*.pdf} %{buildroot}%{_docdir}/%{name}/doc
cp {AUTHORS,ChangeLog,COPYING,NEWS,README} %{buildroot}%{_docdir}/%{name}

%check
make check

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/AUTHORS
%{_docdir}/%{name}/ChangeLog
%{_docdir}/%{name}/COPYING
%{_docdir}/%{name}/NEWS
%{_docdir}/%{name}/README
%{_bindir}/glpsol

%files -n %{lname}
%defattr(-,root,root)
%{_libdir}/libglpk.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/libglpk.so

%files doc
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/doc
%{_docdir}/%{name}/examples

%changelog
* Wed Nov 12 2014 dmitry_r@opensuse.org
- Update to version 4.55
  * Bugfixes, documentation update. See NEWS file for details.
* Mon Mar 31 2014 pgajdos@suse.com
- updated to 4.54
  * Block-triangular LU-factorization was implemented to be used
    on computing an initial factorization of the basis matrix.
  * A new version of the Schur-complement-based factorization
    module was included in the package. Now it can be used along
    with plain as well as with block-triangular LU-factorization.
  * The API routine glp_read_mps was changed to remove free rows.
  * etc. see NEWS for details
* Tue Dec 10 2013 sweet_f_a@gmx.de
- enable tests
* Wed Aug  7 2013 jengelh@inai.de
- Update to new upstream release 4.52.1
  * Version linkage information in the shared library was incorrect
- Set RPM groups according to common practice
- Do optional signature verification
* Thu Jul 25 2013 matwey.kornilov@gmail.com
- use -fno-strict-aliasing to avoid warnings in minisat.c
- don't use dvipdf, docs are in pdf in 4.52
* Thu Jul 25 2013 matwey.kornilov@gmail.com
- updated to 4.52 (see NEWA for details):
  * Some bugs were fixed. Thanks to
    Giorgio Sartor <0gioker0@gmail.com>,
    Xypron <xypron.glpk@gmx.de>,
    David T. Price <dtprice@speakeasy.net>
  * The clique cut generator was essentially reimplemented, and now
    it is able to process very large and/or dense conflict graphs.
  * Singleton and dense phases were implemented on computing
    LU-factorization with Gaussian elimination.
  * A new version of LU-factorization routines were added.
  * The new API routine glp_mincost_relax4, which is a driver to
    relaxation method of Bertsekas and Tseng (RELAX-IV), was added
    to the package.
  * All old API routines whose names begin with 'lpx_'
    were removed from API level and NO MORE AVAILABLE.
* Wed Mar 27 2013 pgajdos@suse.com
- updated to 4.48:
  * This is a maintainer release.
  * Some minor changes in API (glpk.h) were made. For details
    please see ChangeLog.
  * Some bugs/typos were fixed. Thanks to
    Raniere Gaia Costa da Silva,
    Heinrich Schuchardt <xypron.glpk@gmx.de>, and
    Robbie Morrison <robbie@actrix.co.nz> for reports.
* Thu Dec  6 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Avoid manual library dependencies; make doc subpackage noarch
* Mon Oct 31 2011 pgajdos@suse.com
- updated to 4.47 (see NEWS)
* Tue May 24 2011 pgajdos@novell.com
- updated to 4.45 (see NEWS)
* Thu Aug 19 2010 pgajdos@suse.cz
- updated to 4.44 (see NEWS)
* Mon Mar 15 2010 pgajdos@suse.cz
- updated to 4.43 (see NEWS)
* Thu Nov 19 2009 pgajdos@suse.cz
- updated to 4.40 (see NEWS)
* Thu Jun 18 2009 pgajdos@suse.cz
- updated to 4.38 (see NEWS)
* Mon Sep 15 2008 pgajdos@suse.cz
- ghostscript instead of ghostscript-mini in the BuildRequires
  section
* Thu Sep 11 2008 pgajdos@suse.cz
- updated to 4.31:
  * glpspx.h, glpspx01.c, glpspx02.c, glpapi06.c
    The dual simplex solver (spx_dual_opt) was replaced by a new
    implementation of the two-phase dual simplex method (spx_dual).
    Old simplex method routines (spx_prim_opt, spx_prim_feas, and
    spx_dual_opt) were removed from the package.
  * glpk.h, glpscl.h, glpscl.c, glpapi04.c
    New API routine glp_scale_prob was added. It replaces routine
    lpx_scale_prob which is deprecated.
  * glpk.h, glpini.h, glpini01.c, glpini02.c, glpapi05.c
    New API routines glp_std_basis, glp_adv_basis, glp_cpx_basis
    were added. They replace routines lpx_std_basis, lpx_adv_basis,
    lpx_cpx_basis which are deprecated.
  * glpdmp.c
    8-byte data alignment was added to the module (sufficient for
    both ILP32 and LP64 environments).
  * glplib07.c
    16-byte data alignment was added to the module to provide
    compatibility with LP64 environment (8-byte is not sufficient
    due to jmp_buf; thanks to Xypron for investigation).
  * glplpx16.c
    New version of the routine lpx_write_pb was added. Thanks to
    Oscar Gustafsson <oscarg@isy.liu.se> for the contribution.
  * glpspx.h, glpspx03.c, glpapi06.c
    The primal simplex solver (spx_prim_opt, spx_prim_feas) was
    replaced by a new implementation (spx_primal), which currently
    provides the same features as the old version.
  * glpmpl01.c, glpmpl03.c
    Some changes were made in the MathProg translator to allow <,
    <=, >=, and > on comparing symbolic values. Thanks to Heinrich
    Schuchardt <heinrich.schuchardt@gmx.de> for patches.
  * glplpx10.c
    Internal routine set_d_eps in the exact LP solver was changed
    to prevent approximation errors in case of integral data.
    Thanks to Markus Pilz <pilz@cs.uni-bonn.de> for bug report.
  * configure.ac
    The configure script was changed to disable optional features
    by default. For details see file INSTALL.
  * glpipp02.c
    A bug was fixed in the internal routine reduce_bounds. Thanks
    to Anne-Laurence Putz <anne-laurence.putz@eurodecision.com> for
    the bug report.
  * glpapi01.c
    New API routine glp_erase_prob was added.
  * glpapi13.c
    New API routines glp_read_mps and glp_write_mps were added.
    They replace API routines lpx_read_mps, lpx_read_freemps,
    lpx_write_mps, and lpx_write_freemps, which are deprecated.
  * glpapi14.c
    New API routines glp_read_lp and glp_write_lp were added. They
    replace API routines lpx_read_cpxlp and lpx_write_cpxlp, which
    are deprecated.
  * glpsql.c
    Minor bug was fixed. Thanks to Xypron <xypron.glpk@gmx.de> for
    the bug report.
* Mon Aug 18 2008 pgajdos@suse.cz
- fixed glpk.pdf and gmpl.pdf build [bnc#417864]
* Thu Jul  3 2008 pgajdos@suse.cz
- updated to 4.28:
  * Three wrapper routines xdlopen, xdlsym, and xdlclose, which
    provide the shared library support, were added.
  * A static linking to iODBC and MySQL libraries used in the
    MathProg table drivers was replaced by a dynamic linking to
    corresponding shared libraries.
  * Compressed data file support was added.
  * Command-line interface routines were added.
  * bug fixes
* Mon May 19 2008 pgajdos@suse.cz
- sort_pool() defined as void [bnc#319454]
  (void-function.patch)
* Mon Apr  7 2008 pgajdos@suse.cz
- fixed BuildRequires
* Thu Mar 27 2008 pgajdos@suse.cz
- initial version, moved from OBS (project home:akos_ladanyi)
